"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ossUpload = exports.ossPut = exports.createOssInstance = void 0;
var tslib_1 = require("tslib");
var ali_oss_1 = tslib_1.__importDefault(require("ali-oss"));
var path_1 = require("path");
var through2_1 = require("through2");
var ajv_1 = tslib_1.__importDefault(require("ajv"));
var mime_1 = tslib_1.__importDefault(require("mime"));
var optionSchema_1 = require("./optionSchema");
var ajv = new ajv_1.default({ allErrors: false });
/**
 * 创建 ali oss 实例
 * @param options 实例配置
 */
function createOssInstance(options) {
    var aliOssInstance;
    var error;
    return function () {
        if (!aliOssInstance) {
            try {
                aliOssInstance = new ali_oss_1.default({
                    accessKeyId: options.accessKeyId,
                    accessKeySecret: options.accessKeySecret,
                    region: options.region,
                    bucket: options.bucket,
                });
                error = null;
            }
            catch (e) {
                error = e;
            }
        }
        return [aliOssInstance, error];
    };
}
exports.createOssInstance = createOssInstance;
/**
 * oss 上传
 * @param config 上传 put 配置
 */
function ossPut(config) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var dest, file, ossInstance, ossPutOptions, e_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dest = config.dest, file = config.file, ossInstance = config.ossInstance, ossPutOptions = config.ossPutOptions;
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, , 4]);
                    return [4 /*yield*/, ossInstance.put(dest, file.path, ossPutOptions)];
                case 2:
                    _a.sent(); // 上传文件
                    return [2 /*return*/, [true, '']];
                case 3:
                    e_1 = _a.sent();
                    return [2 /*return*/, [false, e_1]];
                case 4: return [2 /*return*/];
            }
        });
    });
}
exports.ossPut = ossPut;
/**
 * gulp oss 上传插件
 * @param options
 */
function ossUpload(options) {
    var _this = this;
    var _a;
    var isValidOssUploadOptions = ajv.validate(optionSchema_1.basicOptionsSchema, options);
    if (!isValidOssUploadOptions) {
        var _b = ((_a = ajv.errors) === null || _a === void 0 ? void 0 : _a.length) ? ajv.errors[0] : {}, _c = _b.message, message = _c === void 0 ? '' : _c, _d = _b.dataPath, dataPath = _d === void 0 ? '' : _d;
        throw new Error("".concat(dataPath, "\uFF0C").concat(message));
    }
    var prefix = options.prefix, ossCreateOptions = options.ossCreateOptions, _e = options.ossPutOptions, ossPutOptions = _e === void 0 ? {} : _e;
    var _f = createOssInstance(ossCreateOptions)(), ossInstance = _f[0], ossCreateError = _f[1];
    if (!ossInstance)
        throw ossCreateError;
    // 通过through2获取文件
    return (0, through2_1.obj)(function (file, _enc, cb) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var defaultPutOptions, _a, isUploadSuccess, uploadError;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    if (file.isDirectory())
                        return [2 /*return*/, cb(null, file)];
                    if (file.isStream())
                        return [2 /*return*/, cb(new Error('No stream support'))];
                    defaultPutOptions = {
                        'Content-Type': mime_1.default.getType(file.path),
                    };
                    return [4 /*yield*/, ossPut({
                            dest: "".concat(prefix, "/").concat((0, path_1.relative)(file.base, file.path).replace(/\\/g, '/')),
                            file: file,
                            ossInstance: ossInstance,
                            ossPutOptions: tslib_1.__assign(tslib_1.__assign({}, defaultPutOptions), ossPutOptions),
                        })];
                case 1:
                    _a = _b.sent(), isUploadSuccess = _a[0], uploadError = _a[1];
                    if (!isUploadSuccess)
                        return [2 /*return*/, cb(uploadError)];
                    return [2 /*return*/, cb(null, file)];
            }
        });
    }); });
}
exports.ossUpload = ossUpload;
//# sourceMappingURL=index.js.map