export const basicOptionsSchema = {
  $schema: 'http://json-schema.org/draft-07/schema',
  $id: 'basicOptionsSchema',
  type: 'object',
  title: 'ossUpload options validate schema',
  description: '校验 ossUpload(options) 函数 options 参数是否正确',
  examples: [
    {
      prefix: '',
      ossCreateOptions: {
        accessKeyId: '',
        accessKeySecret: '',
        region: '',
        bucket: '',
      },
    },
  ],
  required: [
    'prefix',
    'ossCreateOptions',
  ],
  properties: {
    prefix: {
      $id: '#/properties/prefix',
      type: 'string',
      minLength: 1,
      maxLength: 100,
      title: '前缀',
      description: '资源上传 oss 后存储文件夹',
      default: '',
      examples: [
        'boss/xxx',
      ],
    },
    ossCreateOptions: {
      $id: '#/properties/ossCreateOptions',
      type: 'object',
      title: '创建oss参数',
      description: 'ali-oss 创建实例的对象',
      examples: [
        {
          accessKeyId: '',
          accessKeySecret: '',
          region: 'oss-cn-shanghai',
          bucket: 'lixin-assets',
        },
      ],
      required: [
        'accessKeyId',
        'accessKeySecret',
        'region',
        'bucket',
      ],
      properties: {
        accessKeyId: {
          $id: '#/properties/ossCreateOptions/properties/accessKeyId',
          type: 'string',
          minLength: 1,
          maxLength: 200,
        },
        accessKeySecret: {
          $id: '#/properties/ossCreateOptions/properties/accessKeySecret',
          type: 'string',
          minLength: 1,
          maxLength: 200,
        },
        region: {
          $id: '#/properties/ossCreateOptions/properties/region',
          type: 'string',
          minLength: 1,
          maxLength: 200,
          examples: [
            'oss-cn-shanghai',
          ],
        },
        bucket: {
          $id: '#/properties/ossCreateOptions/properties/bucket',
          type: 'string',
          minLength: 1,
          maxLength: 200,
          examples: [
            'lixin-assets',
          ],
        },
      },
      additionalProperties: true,
    },
  },
  additionalProperties: true,
};

export default {
  basicOptionsSchema,
};
